// https://nuxt.com/docs/api/configuration/nuxt-config

// See https://blog.csdn.net/m0_53022813/article/details/137379480
import eslintPlugin from 'vite-plugin-eslint'

export default defineNuxtConfig({
  modules: ['@pinia/nuxt', '@pinia-plugin-persistedstate/nuxt', '@nuxt/image', '@nuxt/eslint'],
  components: true,
  devtools: { enabled: false },
  app: {
    head: {
      title: 'CANTYONION.SITE',
      meta: [
        { name: 'viewport', content: 'width=device-width, initial-scale=1' },
        { name: 'charset', content: 'utf-8' },
        { name: 'keywords', content: 'cantyonion, onion, 洋葱, 博客, 学习, 主页, index' },
        { name: 'description', content: 'cantyonion的超级基地，进来看看吧！' },
      ],
      link: [
        { rel: 'icon', href: '/favicon.png' },
      ],
    },
  },
  css: [
    '@fortawesome/fontawesome-svg-core/styles.css',
    'github-markdown-css/github-markdown-light.css',
    '~/assets/css/main.scss',
  ],
  runtimeConfig: {
    public: {
      gitApiKey: 'fb8aec429ea7d0a36f7238dbffda9d2d66c7b045',
      baseURL: 'https://cantyonion.site',
    },
  },
  build: {
    transpile: ['@fortawesome/vue-fontawesome', 'vue3-typed-js', 'pinia-plugin-persistedstate'],
  },
  devServer: {
    host: '0.0.0.0',
  },
  compatibilityDate: '2024-04-03',
  vite: {
    plugins: [
      eslintPlugin({
        include: ['**/*.ts', '**/*.vue'],
      }),
    ],
    css: {
      preprocessorOptions: {
        scss: {
          api: 'modern-compiler', // Or "modern"
        },
      },
    },
  },
  postcss: {
    plugins: {
      tailwindcss: {},
      autoprefixer: {},
    },
  },
  eslint: {
    config: {
      stylistic: true,
    },
  },
})
